==> enable-5.1.1.tar.gz: enable-5.1.1/kiva/fonttools/_constants.py <==
# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

font_family_aliases = {
    "serif",
    "sans-serif",
    "sans serif",
    "cursive",
    "fantasy",
    "monospace",
    "sans",
    "modern",
}

preferred_fonts = {
    "fantasy": [
        "Comic Sans MS",
        "Chicago",
        "Charcoal",
        "ImpactWestern",
        "fantasy",
    ],
    "cursive": [
        "Apple Chancery",
        "Textile",
        "Zapf Chancery",
        "Sand",
        "cursive",
    ],
    "monospace": [
        "Bitstream Vera Sans Mono",
        "DejaVu Sans Mono",
        "Andale Mono",
        "Nimbus Mono L",
        "Courier New",
        "Courier",
        "Fixed",
        "Terminal",
        "monospace",
    ],
    "serif": [
        "Bitstream Vera Serif",
        "DejaVu Serif",
        "New Century Schoolbook",
        "Century Schoolbook L",
        "Utopia",
        "ITC Bookman",
        "Bookman",
        "Nimbus Roman No9 L",
        "Times New Roman",
        "Times",
        "Palatino",
        "Charter",
        "serif",
    ],
    "sans-serif": [
        "Bitstream Vera Sans",
        "DejaVu Sans",
        "Helvetica Neue",
        "Arial",
        "Verdana",
        "Helvetica",
        "Lucida Grande",
        "Geneva",
        "Lucid",
        "Avant Garde",
        "sans-serif",
    ],
}

stretch_dict = {
    "ultra-condensed": 100,
    "extra-condensed": 200,
    "condensed": 300,
    "semi-condensed": 400,
    "normal": 500,
    "semi-expanded": 600,
    "expanded": 700,
    "extra-expanded": 800,
    "ultra-expanded": 900,
}

weight_dict = {
    "ultralight": 100,
    "light": 200,
    "normal": 400,
    "regular": 400,
    "book": 400,
    "medium": 500,
    "roman": 500,
    "semibold": 600,
    "demibold": 600,
    "demi": 600,
    "bold": 700,
    "heavy": 800,
    "extra bold": 800,
    "black": 900,
}

==> enable-5.3.1.tar.gz: enable-5.3.1/kiva/fonttools/_constants.py <==
# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
# All rights reserved.
#
# This software is provided without warranty under the terms of the BSD
# license included in LICENSE.txt and may be redistributed only under
# the conditions described in the aforementioned license. The license
# is also available online at http://www.enthought.com/licenses/BSD.txt
#
# Thanks for using Enthought open source!

font_family_aliases = {
    "serif",
    "sans-serif",
    "sans serif",
    "cursive",
    "fantasy",
    "monospace",
    "sans",
    "modern",
}

preferred_fonts = {
    "fantasy": [
        "Comic Sans MS",
        "Chicago",
        "Charcoal",
        "ImpactWestern",
        "fantasy",
    ],
    "cursive": [
        "Apple Chancery",
        "Textile",
        "Zapf Chancery",
        "Sand",
        "cursive",
    ],
    "monospace": [
        "Bitstream Vera Sans Mono",
        "DejaVu Sans Mono",
        "Andale Mono",
        "Nimbus Mono L",
        "Courier New",
        "Courier",
        "Fixed",
        "Terminal",
        "monospace",
    ],
    "serif": [
        "Bitstream Vera Serif",
        "DejaVu Serif",
        "New Century Schoolbook",
        "Century Schoolbook L",
        "Utopia",
        "ITC Bookman",
        "Bookman",
        "Nimbus Roman No9 L",
        "Times New Roman",
        "Times",
        "Palatino",
        "Charter",
        "serif",
    ],
    "sans-serif": [
        "Bitstream Vera Sans",
        "DejaVu Sans",
        "Helvetica Neue",
        "Arial",
        "Verdana",
        "Helvetica",
        "Lucida Grande",
        "Geneva",
        "Lucid",
        "Avant Garde",
        "sans-serif",
    ],
}

stretch_dict = {
    "ultra-condensed": 100,
    "extra-condensed": 200,
    "condensed": 300,
    "semi-condensed": 400,
    "normal": 500,
    "semi-expanded": 600,
    "expanded": 700,
    "extra-expanded": 800,
    "ultra-expanded": 900,
}

weight_dict = {
    'thin': 100,
    'hairline': 100,
    'extralight': 200,
    'ultralight': 200,
    'light': 300,
    'normal': 400,
    'regular': 400,
    'book': 400,
    'medium': 500,
    'roman': 500,
    'semibold': 600,
    'demibold': 600,
    'demi': 600,
    'bold': 700,
    'extrabold': 800,
    'ultrabold': 800,
    'black': 900,
    'heavy': 900,
    'extraheavy': 1000,
}
